From sjr@comcast.net  Fri Dec 22 15:05:46 2006
Return-Path: <sjr@comcast.net>
Received: from mx1.freebsd.org (mx1.freebsd.org [69.147.83.52])
	by hub.freebsd.org (Postfix) with ESMTP id 52D1C16A50A
	for <FreeBSD-gnats-submit@freebsd.org>; Fri, 22 Dec 2006 15:05:46 +0000 (UTC)
	(envelope-from sjr@comcast.net)
Received: from alnrmhc13.comcast.net (alnrmhc13.comcast.net [206.18.177.53])
	by mx1.freebsd.org (Postfix) with ESMTP id 1786813C4B3
	for <FreeBSD-gnats-submit@freebsd.org>; Fri, 22 Dec 2006 15:05:45 +0000 (UTC)
	(envelope-from sjr@comcast.net)
Received: from istari.comcast.net (c-68-32-119-244.hsd1.md.comcast.net[68.32.119.244](misconfigured sender))
          by comcast.net (alnrmhc13) with ESMTP
          id <20061222150544b1300q809oe>; Fri, 22 Dec 2006 15:05:45 +0000
Received: from istari.comcast.net (localhost [127.0.0.1])
	by istari.comcast.net (8.13.8/8.13.8) with ESMTP id kBMF5h3N005276;
	Fri, 22 Dec 2006 10:05:43 -0500 (EST)
	(envelope-from sjr@istari.comcast.net)
Received: (from sjr@localhost)
	by istari.comcast.net (8.13.8/8.13.8/Submit) id kBMF5hIg005275;
	Fri, 22 Dec 2006 10:05:43 -0500 (EST)
	(envelope-from sjr)
Message-Id: <200612221505.kBMF5hIg005275@istari.comcast.net>
Date: Fri, 22 Dec 2006 10:05:43 -0500 (EST)
From: "Stephen J. Roznowski" <sjr@comcast.net>
Reply-To: "Stephen J. Roznowski" <sjr@comcast.net>
To: FreeBSD-gnats-submit@freebsd.org
Cc: sos@freebsd.org
Subject: Typo in ata-queue.c
X-Send-Pr-Version: 3.113
X-GNATS-Notify:

>Number:         107100
>Category:       kern
>Synopsis:       Typo in ata-queue.c
>Confidential:   no
>Severity:       non-critical
>Priority:       low
>Responsible:    remko
>State:          closed
>Quarter:        
>Keywords:       
>Date-Required:  
>Class:          change-request
>Submitter-Id:   current-users
>Arrival-Date:   Fri Dec 22 15:10:22 GMT 2006
>Closed-Date:    Sat Dec 23 12:41:43 GMT 2006
>Last-Modified:  Fri Feb  2 08:00:28 GMT 2007
>Originator:     Stephen J. Roznowski
>Release:        FreeBSD 6.2-PRERELEASE amd64
>Organization:
>Environment:
System: FreeBSD 6.2-PRERELEASE: Sun Nov 19 15:43:58 EST 2006 amd64


	
>Description:
	
	Completion is misspelled in ata-queue.c
>How-To-Repeat:
	
>Fix:

	

--- sys/dev/ata/ata-queue.c.orig	Fri Dec 22 09:59:37 2006
+++ sys/dev/ata/ata-queue.c	Fri Dec 22 10:00:21 2006
@@ -101,7 +101,7 @@
 
     /* if this is not a callback wait until request is completed */
     if (!request->callback) {
-	ATA_DEBUG_RQ(request, "wait for completition");
+	ATA_DEBUG_RQ(request, "wait for completion");
 	if (!dumping &&
 	    sema_timedwait(&request->done, request->timeout * hz * 4)) {
 	    device_printf(request->dev,
@@ -240,7 +240,7 @@
 	ata_completed(request, 0);
     }
     else {
 	/* put request on the proper taskqueue for completition */
 	if (request->bio && !(request->flags & (ATA_R_THREAD | ATA_R_TIMEOUT))){
 	    ATA_DEBUG_RQ(request, "finish bio_taskqueue");
 	    bio_taskqueue(request->bio, (bio_task_t *)ata_completed, request);
@@ -240,7 +240,7 @@
     }
     else {
-	/* put request on the proper taskqueue for completition */
+	/* put request on the proper taskqueue for completion */
 	if (request->bio && !(request->flags & (ATA_R_THREAD | ATA_R_TIMEOUT))){
 	    ATA_DEBUG_RQ(request, "finish bio_taskqueue");
>Release-Note:
>Audit-Trail:
Responsible-Changed-From-To: freebsd-bugs->remko 
Responsible-Changed-By: remko 
Responsible-Changed-When: Sat Dec 23 11:59:17 UTC 2006 
Responsible-Changed-Why:  
I got permission for Soren to commit this, let me handle the ticket 
as well. 

http://www.freebsd.org/cgi/query-pr.cgi?pr=107100 
State-Changed-From-To: open->closed 
State-Changed-By: remko 
State-Changed-When: Sat Dec 23 12:41:42 UTC 2006 
State-Changed-Why:  
I have committed the typo change, thanks for the submission! 

http://www.freebsd.org/cgi/query-pr.cgi?pr=107100 

From: dfilter@FreeBSD.ORG (dfilter service)
To: bug-followup@FreeBSD.org
Cc:  
Subject: Re: kern/107100: commit references a PR
Date: Sat, 23 Dec 2006 12:41:00 +0000 (UTC)

 remko       2006-12-23 12:40:54 UTC
 
   FreeBSD src repository (doc committer)
 
   Modified files:
     sys/dev/ata          ata-queue.c 
   Log:
   Fix a typo in ata-queue.c
   
   PR:             kern/107100
   Submitted by:   Stephen J. Roznowski <sjr at comcast dot net>
   Approved by:    sos
   
   Revision  Changes    Path
   1.66      +2 -2      src/sys/dev/ata/ata-queue.c
 _______________________________________________
 cvs-all@freebsd.org mailing list
 http://lists.freebsd.org/mailman/listinfo/cvs-all
 To unsubscribe, send any mail to "cvs-all-unsubscribe@freebsd.org"
 

From: dfilter@FreeBSD.ORG (dfilter service)
To: bug-followup@FreeBSD.org
Cc:  
Subject: Re: kern/107100: commit references a PR
Date: Fri,  2 Feb 2007 07:42:59 +0000 (UTC)

 remko       2007-02-02 07:42:44 UTC
 
   FreeBSD src repository (doc committer)
 
   Modified files:        (Branch: RELENG_6)
     sys/sys              ata.h 
     sys/dev/ata          ata-queue.c 
   Log:
   MFC:
   
     Fix a typo in ata-queue.c
   
     PR:             kern/107100
     Submitted by:   Stephen J. Roznowski <sjr at comcast dot net>
     Approved by:    sos
   
   and
   
     Add the SMART command to the ATA instruction set.
     When the disk has an error, it will now print SMART
     instead of 'Unknown CMD'.
   
     PR:             kern/93368
     Submitted by:   Garry Belka <garry at NetworkPhysics dot COM>
     Approved by:    sos
   
   Approved by:    sos (implicitly with the previous two commits)
   
   Revision  Changes    Path
   1.50.2.7  +3 -2      src/sys/dev/ata/ata-queue.c
   1.26.2.6  +1 -0      src/sys/sys/ata.h
 _______________________________________________
 cvs-all@freebsd.org mailing list
 http://lists.freebsd.org/mailman/listinfo/cvs-all
 To unsubscribe, send any mail to "cvs-all-unsubscribe@freebsd.org"
 

From: dfilter@FreeBSD.ORG (dfilter service)
To: bug-followup@FreeBSD.org
Cc:  
Subject: Re: kern/107100: commit references a PR
Date: Fri,  2 Feb 2007 07:54:18 +0000 (UTC)

 remko       2007-02-02 07:54:10 UTC
 
   FreeBSD src repository (doc committer)
 
   Modified files:        (Branch: RELENG_5)
     sys/dev/ata          ata-queue.c 
     sys/sys              ata.h 
   Log:
   MFC:
   
     Fix a typo in ata-queue.c
   
     PR:             kern/107100
     Submitted by:   Stephen J. Roznowski <sjr at comcast dot net>
     Approved by:    sos
   
   and
   
     Add the SMART command to the ATA instruction set.
     When the disk has an error, it will now print SMART
     instead of 'Unknown CMD'.
   
     PR:             kern/93368
     Submitted by:   Garry Belka <garry at NetworkPhysics dot COM>
     Approved by:    sos
   
   Approved by:    sos (implicitly with the two previous commits).
   
   Revision  Changes    Path
   1.32.2.9  +3 -2      src/sys/dev/ata/ata-queue.c
   1.23.2.1  +1 -0      src/sys/sys/ata.h
 _______________________________________________
 cvs-all@freebsd.org mailing list
 http://lists.freebsd.org/mailman/listinfo/cvs-all
 To unsubscribe, send any mail to "cvs-all-unsubscribe@freebsd.org"
 
>Unformatted:
